@@ -519,10 +519,11 @@ protected:
 	MyAction * incAudioDelayAct;
 	MyAction * audioDelayAct; // Ask for delay
 	MyAction * extrastereoAct;
-#ifdef MPLAYER_SUPPORT
 	MyAction * karaokeAct;
-#endif
 	MyAction * volnormAct;
+#ifdef MPV_SUPPORT
+	MyAction * earwaxAct;
+#endif
 	MyAction * loadAudioAct;
 	MyAction * unloadAudioAct;
 
@@ -738,7 +739,7 @@ protected:
 
 	// Audio Channels Action Group
 	MyActionGroup * channelsGroup;
-	/* MyAction * channelsDefaultAct; */
+	MyAction * channelsDefaultAct;
 	MyAction * channelsStereoAct;
 	MyAction * channelsSurroundAct;
 	MyAction * channelsFull51Act;
