@@ -71,12 +71,17 @@ using namespace Global;
 
 BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
 	: BaseGui( parent, flags )
+#ifdef USE_SYSTRAY
+	, context_menu(0)
+#endif
 #ifdef SCREENS_SUPPORT
 	, screens_info_window(0)
 	, detached_label(0)
 #endif
 	, mainwindow_visible(true)
+#ifdef USE_SYSTRAY
 	, trayicon_playlist_was_visible(false)
+#endif
 	, widgets_size(0)
 #if DOCK_PLAYLIST
 	, fullscreen_playlist_was_visible(false)
@@ -89,15 +94,16 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
 	//infowindow_visible = false;
 	mainwindow_pos = pos();
 
+	quitAct = new MyAction(QKeySequence("Ctrl+Q"), this, "quit");
+	connect( quitAct, SIGNAL(triggered()), this, SLOT(quit()) );
+
+#ifdef USE_SYSTRAY
 	tray = new QSystemTrayIcon(this);
 
 	tray->setToolTip( "SMPlayer" );
 	connect( tray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), 
              this, SLOT(trayIconActivated(QSystemTrayIcon::ActivationReason)));
 
-	quitAct = new MyAction(QKeySequence("Ctrl+Q"), this, "quit");
-	connect( quitAct, SIGNAL(triggered()), this, SLOT(quit()) );
-
 	showTrayAct = new MyAction(this, "show_tray_icon" );
 	showTrayAct->setCheckable(true);
 	connect( showTrayAct, SIGNAL(toggled(bool)),
@@ -107,32 +113,9 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
 	connect( showAllAct, SIGNAL(triggered()),
              this, SLOT(toggleShowAll()) );
 
-	context_menu = new QMenu(this);
-	context_menu->addAction(showAllAct);
-	context_menu->addSeparator();
-	context_menu->addAction(openFileAct);
-	context_menu->addMenu(recentfiles_menu);
-	context_menu->addAction(openDirectoryAct);
-	context_menu->addAction(openDVDAct);
-	context_menu->addAction(openURLAct);
-	context_menu->addMenu(favorites);
-#if defined(TV_SUPPORT) && !defined(Q_OS_WIN)
-	context_menu->addMenu(tvlist);
-	context_menu->addMenu(radiolist);
+	// The systray menu will be initialized later in
+	// the function populateMainMenu
 #endif
-	context_menu->addSeparator();
-	context_menu->addAction(playOrPauseAct);
-	context_menu->addAction(stopAct);
-	context_menu->addSeparator();
-	context_menu->addAction(playPrevAct);
-	context_menu->addAction(playNextAct);
-	context_menu->addSeparator();
-	context_menu->addAction(showPlaylistAct);
-	context_menu->addAction(showPreferencesAct);
-	context_menu->addSeparator();
-	context_menu->addAction(quitAct);
-
-	tray->setContextMenu( context_menu );
 
 #if DOCK_PLAYLIST
 	// Playlistdock
@@ -232,7 +215,10 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags)
 
 BaseGuiPlus::~BaseGuiPlus() {
 	saveConfig();
+
+#ifdef USE_SYSTRAY
 	tray->hide();
+#endif
 
 #ifdef CHROMECAST_SUPPORT
 	Chromecast::deleteInstance();
@@ -246,7 +232,9 @@ void BaseGuiPlus::populateMainMenu() {
 
 	if (!pref->tablet_mode) {
 		openMenu->addAction(quitAct);
+		#ifdef USE_SYSTRAY
 		optionsMenu->addAction(showTrayAct);
+		#endif
 	}
 
 #ifdef DETACH_VIDEO_OPTION
@@ -272,13 +260,21 @@ void BaseGuiPlus::populateMainMenu() {
 	playMenu->addSeparator();
 	playMenu->addAction(playOnChromecastAct);
 #endif
+
+#ifdef USE_SYSTRAY
+	if (context_menu == 0) initializeSystrayMenu();
+#endif
 }
 
 bool BaseGuiPlus::startHidden() {
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	return false;
 #else
-	if ( (!showTrayAct->isChecked()) || (mainwindow_visible) ) 
+	#ifdef USE_SYSTRAY
+	if (!showTrayAct->isChecked() || mainwindow_visible)
+	#else
+	if (mainwindow_visible)
+	#endif
 		return false;
 	else
 		return true;
@@ -304,6 +300,9 @@ void BaseGuiPlus::updateWidgets() {
 void BaseGuiPlus::closeWindow() {
 	qDebug("BaseGuiPlus::closeWindow");
 
+#ifndef USE_SYSTRAY
+	BaseGui::closeWindow();
+#else
 	if (tray->isVisible()) {
 		//e->ignore();
 		exitFullscreen();
@@ -316,12 +315,11 @@ void BaseGuiPlus::closeWindow() {
         	    QSystemTrayIcon::Information, 3000 );
 			pref->balloon_count--;
 		}
-
 	} else {
 		BaseGui::closeWindow();
 	}
 	//tray->hide();
-
+#endif
 }
 
 void BaseGuiPlus::quit() {
@@ -332,12 +330,13 @@ void BaseGuiPlus::quit() {
 void BaseGuiPlus::retranslateStrings() {
 	BaseGui::retranslateStrings();
 
-	tray->setIcon(Images::icon("logo", 22));
-
 	quitAct->change( Images::icon("exit"), tr("&Quit") );
-	showTrayAct->change( Images::icon("systray"), tr("S&how icon in system tray") );
 
+#ifdef USE_SYSTRAY
+	tray->setIcon(Images::icon("logo", 22));
+	showTrayAct->change( Images::icon("systray"), tr("S&how icon in system tray") );
 	updateShowAllAct();
+#endif
 
 #if DOCK_PLAYLIST
 	// playlistdock->setWindowTitle( tr("Playlist") );
@@ -366,12 +365,44 @@ void BaseGuiPlus::retranslateStrings() {
 #endif
 }
 
+#ifdef USE_SYSTRAY
+void BaseGuiPlus::initializeSystrayMenu() {
+	qDebug("BaseGuiPlus::initializeSystrayMenu");
+	context_menu = new QMenu(this);
+	context_menu->addAction(showAllAct);
+	context_menu->addSeparator();
+	context_menu->addAction(openFileAct);
+	context_menu->addMenu(recentfiles_menu);
+	context_menu->addAction(openDirectoryAct);
+	context_menu->addAction(openDVDAct);
+	context_menu->addAction(openURLAct);
+	context_menu->addMenu(favorites);
+#if defined(TV_SUPPORT) && !defined(Q_OS_WIN)
+	context_menu->addMenu(tvlist);
+	context_menu->addMenu(radiolist);
+#endif
+	context_menu->addSeparator();
+	context_menu->addAction(playOrPauseAct);
+	context_menu->addAction(stopAct);
+	context_menu->addSeparator();
+	context_menu->addAction(playPrevAct);
+	context_menu->addAction(playNextAct);
+	context_menu->addSeparator();
+	context_menu->addAction(showPlaylistAct);
+	context_menu->addAction(showPreferencesAct);
+	context_menu->addSeparator();
+	context_menu->addAction(quitAct);
+
+	tray->setContextMenu(context_menu);
+}
+
 void BaseGuiPlus::updateShowAllAct() {
 	if (isVisible()) 
 		showAllAct->change( tr("&Hide") );
 	else
 		showAllAct->change( tr("&Restore") );
 }
+#endif
 
 void BaseGuiPlus::saveConfig() {
 	qDebug("BaseGuiPlus::saveConfig");
@@ -380,10 +411,12 @@ void BaseGuiPlus::saveConfig() {
 
 	set->beginGroup( "base_gui_plus");
 
+#ifdef USE_SYSTRAY
 	set->setValue( "show_tray_icon", showTrayAct->isChecked() );
+	set->setValue( "trayicon_playlist_was_visible", trayicon_playlist_was_visible );
+#endif
 	set->setValue( "mainwindow_visible", isVisible() );
 
-	set->setValue( "trayicon_playlist_was_visible", trayicon_playlist_was_visible );
 	set->setValue( "widgets_size", widgets_size );
 #if DOCK_PLAYLIST
 	set->setValue( "fullscreen_playlist_was_visible", fullscreen_playlist_was_visible );
@@ -408,13 +441,15 @@ void BaseGuiPlus::loadConfig() {
 
 	set->beginGroup( "base_gui_plus");
 
+#ifdef USE_SYSTRAY
 	bool show_tray_icon = set->value( "show_tray_icon", false).toBool();
 	showTrayAct->setChecked( show_tray_icon );
 	//tray->setVisible( show_tray_icon );
+	trayicon_playlist_was_visible = set->value( "trayicon_playlist_was_visible", trayicon_playlist_was_visible ).toBool();
+#endif
 
 	mainwindow_visible = set->value("mainwindow_visible", true).toBool();
 
-	trayicon_playlist_was_visible = set->value( "trayicon_playlist_was_visible", trayicon_playlist_was_visible ).toBool();
 	widgets_size = set->value( "widgets_size", widgets_size ).toInt();
 #if DOCK_PLAYLIST
 	fullscreen_playlist_was_visible = set->value( "fullscreen_playlist_was_visible", fullscreen_playlist_was_visible ).toBool();
@@ -431,10 +466,12 @@ void BaseGuiPlus::loadConfig() {
 
 	set->endGroup();
 
+#ifdef USE_SYSTRAY
 	updateShowAllAct();
+#endif
 }
 
-
+#ifdef USE_SYSTRAY
 void BaseGuiPlus::trayIconActivated(QSystemTrayIcon::ActivationReason reason) {
 	qDebug("DefaultGui::trayIconActivated: %d", reason);
 
@@ -512,11 +549,14 @@ void BaseGuiPlus::showAll(bool b) {
 	}
 	updateShowAllAct();
 }
+#endif
 
 void BaseGuiPlus::resizeWindow(int w, int h) {
     qDebug("BaseGuiPlus::resizeWindow: %d, %d", w, h);
 
+#ifdef USE_SYSTRAY
 	if ( (tray->isVisible()) && (!isVisible()) ) showAll(true);
+#endif
 
 	BaseGui::resizeWindow(w, h );
 }
@@ -525,11 +565,15 @@ void BaseGuiPlus::updateMediaInfo() {
 	qDebug("BaseGuiPlus::updateMediaInfo");
 	BaseGui::updateMediaInfo();
 
+#ifdef USE_SYSTRAY
 	tray->setToolTip( windowTitle() );
+#endif
 }
 
 void BaseGuiPlus::setWindowCaption(const QString & title) {
+#ifdef USE_SYSTRAY
 	tray->setToolTip( title );
+#endif
 
 	BaseGui::setWindowCaption( title );
 }
@@ -942,6 +986,9 @@ void BaseGuiPlus::sendVideoToScreen(int screen) {
 		//is_primary_screen = false;
 		if (is_primary_screen) {
 			mplayerwindow->showNormal();
+			#if QT_VERSION >= 0x050000 && defined(Q_OS_LINUX)
+			qApp->processEvents();
+			#endif
 			detachVideo(false);
 		} else {
 			detachVideo(true);
@@ -987,6 +1034,9 @@ void BaseGuiPlus::detachVideo(bool detach) {
 
 			mplayerwindow->setWindowTitle(QString::null);
 			mplayerwindow->setParent(panel);
+			#if QT_VERSION >= 0x050000 && defined(Q_OS_LINUX)
+			qApp->processEvents();
+			#endif
 			panel->layout()->addWidget(mplayerwindow);
 		}
 	}
