@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@ FindSubtitlesConfigDialog::FindSubtitlesConfigDialog( QWidget* parent, Qt::Windo
 {
 	setupUi(this);
 
+	search_method_combo->addItem(tr("Hash"), Hash);
+	search_method_combo->addItem(tr("Filename"), Filename);
+
 #ifdef FS_USE_PROXY
 	proxy_type_combo->addItem( tr("HTTP"), QNetworkProxy::HttpProxy);
 	proxy_type_combo->addItem( tr("SOCKS5"), QNetworkProxy::Socks5Proxy);
@@ -49,12 +52,22 @@ FindSubtitlesConfigDialog::FindSubtitlesConfigDialog( QWidget* parent, Qt::Windo
 	misc_group->hide();
 #endif
 
+#ifndef FS_USE_SERVER_CONFIG
+	server_label->hide();
+	server_edit->hide();
+#endif
+
+#if !defined(FS_USE_SERVER_CONFIG) && !defined(OS_SEARCH_WORKAROUND)
+	server_group->hide();
+#endif
+
 	layout()->setSizeConstraint(QLayout::SetFixedSize);
 }
 
 FindSubtitlesConfigDialog::~FindSubtitlesConfigDialog() {
 }
 
+#ifdef FS_USE_SERVER_CONFIG
 void FindSubtitlesConfigDialog::setServer(QString server) {
 	server_edit->setText(server);
 }
@@ -62,6 +75,17 @@ void FindSubtitlesConfigDialog::setServer(QString server) {
 QString FindSubtitlesConfigDialog::server() {
 	return server_edit->text();
 }
+#endif
+
+void FindSubtitlesConfigDialog::setSearchMethod(SearchMethod m) {
+	int pos = search_method_combo->findData(m);
+	if (pos == -1) pos = 0;
+	search_method_combo->setCurrentIndex(pos);
+}
+
+int FindSubtitlesConfigDialog::searchMethod() {
+	return search_method_combo->itemData(search_method_combo->currentIndex()).toInt();
+}
 
 #ifdef OS_SEARCH_WORKAROUND
 void FindSubtitlesConfigDialog::setRetries(int n) {
