@@ -95,11 +95,12 @@ void MediaSettings::reset() {
 	add_letterbox = false;
 #endif
 
-#ifdef MPLAYER_SUPPORT
 	karaoke_filter = false;
-#endif
 	extrastereo_filter = false;
 	volnorm_filter = pref->initial_volnorm;
+#ifdef MPV_SUPPORT
+	earwax_filter = false;
+#endif
 
 	audio_use_channels = pref->initial_audio_channels; //ChDefault; // (0)
 	stereo_mode = pref->initial_stereo_mode; //Stereo; // (0)
@@ -253,11 +254,12 @@ void MediaSettings::list() {
 
 	qDebug("  add_letterbox: %d", add_letterbox);
 
-#ifdef MPLAYER_SUPPORT
 	qDebug("  karaoke_filter: %d", karaoke_filter);
-#endif
 	qDebug("  extrastereo_filter: %d", extrastereo_filter);
 	qDebug("  volnorm_filter: %d", volnorm_filter);
+#ifdef MPV_SUPPORT
+	qDebug("  earwax_filter: %d", earwax_filter);
+#endif
 
 	qDebug("  audio_use_channels: %d", audio_use_channels);
 	qDebug("  stereo_mode: %d", stereo_mode);
@@ -384,13 +386,14 @@ void MediaSettings::save(QSettings * set, int player_id) {
 
 	set->setValue( "add_letterbox", add_letterbox );
 
-#ifdef MPLAYER_SUPPORT
 	set->setValue( "karaoke_filter", karaoke_filter);
-#endif
 	set->setValue( "extrastereo_filter", extrastereo_filter);
 	set->setValue( "volnorm_filter", volnorm_filter);
+#ifdef MPV_SUPPORT
+	set->setValue( "earwax_filter", earwax_filter);
+#endif
 
-	set->setValue( "audio_use_channels", audio_use_channels);
+	set->setValue( "audio_channels", audio_use_channels);
 	set->setValue( "stereo_mode", stereo_mode);
 
 	set->setValue( "zoom_factor", zoom_factor);
@@ -522,13 +525,14 @@ void MediaSettings::load(QSettings * set, int player_id) {
 
 	add_letterbox = set->value( "add_letterbox", add_letterbox ).toBool();
 
-#ifdef MPLAYER_SUPPORT
 	karaoke_filter = set->value( "karaoke_filter", karaoke_filter).toBool();
-#endif
 	extrastereo_filter = set->value( "extrastereo_filter", extrastereo_filter).toBool();
 	volnorm_filter = set->value( "volnorm_filter", volnorm_filter).toBool();
+#ifdef MPV_SUPPORT
+	earwax_filter = set->value( "earwax_filter", earwax_filter).toBool();
+#endif
 
-	audio_use_channels = set->value( "audio_use_channels", audio_use_channels).toInt();
+	audio_use_channels = set->value( "audio_channels", audio_use_channels).toInt();
 	stereo_mode = set->value( "stereo_mode", stereo_mode).toInt();
 
 	zoom_factor = set->value( "zoom_factor", zoom_factor).toDouble();
@@ -570,6 +574,6 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	is264andHD = set->value( "is264andHD", is264andHD ).toBool();
 
 	// ChDefault not used anymore
-	if (audio_use_channels == ChDefault) audio_use_channels = ChStereo;
+	//if (audio_use_channels == ChDefault) audio_use_channels = ChStereo;
 }
 
