@@ -129,6 +129,10 @@ void MplayerProcess::setOption(const QString & option_name, const QVariant & val
 		// Not supported
 	}
 	else
+	if (option_name == "ytdl_quality") {
+		// Not supported
+	}
+	else
 	if (option_name == "hwdec") {
 		// Not supported
 	}
@@ -223,6 +227,14 @@ void MplayerProcess::addVF(const QString & filter_name, const QVariant & value)
 		arg << "-vf-add" << "harddup,flip";
 	}
 	else
+	if (filter_name == "letterbox") {
+		QSize desktop_size = value.toSize();
+		double aspect = (double) desktop_size.width() / desktop_size.height();
+		arg << "-vf-add" << "expand=aspect=" + QString::number(aspect) + ",harddup";
+		// harddup fixes subtitles not disappearing
+	}
+	/*
+	else
 	if (filter_name == "expand") {
 		arg << "-vf-add" << "expand=" + option + ",harddup";
 		// Note: on some videos (h264 for instance) the subtitles doesn't disappear,
@@ -230,6 +242,7 @@ void MplayerProcess::addVF(const QString & filter_name, const QVariant & value)
 		// filter after expand fixes the problem. I chose harddup 'cos I think
 		// it will be harmless in mplayer.
 	}
+	*/
 	else {
 		QString s = filter_name;
 		QString option = value.toString();
@@ -244,10 +257,43 @@ void MplayerProcess::addStereo3DFilter(const QString & in, const QString & out)
 	arg << "-vf-add" << filter;
 }
 
+void MplayerProcess::setVideoEqualizerOptions(int contrast, int brightness, int hue, int saturation, int gamma, bool soft_eq) {
+	if (contrast != 0) arg << "-contrast" << QString::number(contrast);
+	if (brightness != 0) arg << "-brightness" << QString::number(brightness);
+	if (hue != 0) arg << "-hue" << QString::number(hue);
+	if (saturation != 0) arg << "-saturation" << QString::number(saturation);
+	if (gamma != 0) arg << "-gamma" << QString::number(gamma);
+
+	if (soft_eq) {
+		arg << "-vf-add" << "eq2,hue";
+	}
+}
+
 void MplayerProcess::addAF(const QString & filter_name, const QVariant & value) {
 	QString s = filter_name;
-	if (!value.isNull()) s += "=" + value.toString();
-	arg << "-af-add" << s;
+	if (filter_name == "earwax") {
+		// Not supported
+	}
+	else
+	if (filter_name == "stereo-mode") {
+		QString o = value.toString();
+		if (o == "left") arg << "-af-add" << "channels=2:2:0:1:0:0";
+		else
+		if (o == "right") arg << "-af-add" << "channels=2:2:1:0:1:1";
+		else
+		if (o == "reverse") arg << "-af-add" << "channels=2:2:0:1:1:0";
+		else
+		if (o == "mono") arg << "-af-add" << "pan=1:0.5:0.5";
+	}
+	else
+	if (filter_name == "equalizer") {
+		AudioEqualizerList l = value.toList();
+		QString o = AudioEqualizerHelper::equalizerListToString(l);
+		arg << "-af-add" << "equalizer=" + o;
+	} else {
+		if (!value.isNull()) s += "=" + value.toString();
+		arg << "-af-add" << s;
+	}
 }
 
 void MplayerProcess::quit() {
@@ -412,7 +458,8 @@ void MplayerProcess::enableVolnorm(bool b, const QString & option) {
 	if (b) writeToStdin("af_add volnorm=" + option); else writeToStdin("af_del volnorm");
 }
 
-void MplayerProcess::setAudioEqualizer(const QString & values) {
+void MplayerProcess::setAudioEqualizer(AudioEqualizerList l) {
+	QString values = AudioEqualizerHelper::equalizerListToString(l);
 	writeToStdin("af_cmdline equalizer " + values);
 }
 
@@ -497,10 +544,20 @@ void MplayerProcess::setOSDScale(double /*value*/) {
 	/* writeToStdin("set_property subfont-osd-scale " + QString::number(value)); */
 }
 
-void MplayerProcess::changeVF(const QString & /*filter*/, bool /*enable*/, const QVariant & /*option*/) {
+void MplayerProcess::changeVF(const QString & filter, bool enable, const QVariant & option) {
 	// not supported
+	Q_UNUSED(filter);
+	Q_UNUSED(enable);
+	Q_UNUSED(option);
 }
 
+void MplayerProcess::changeAF(const QString & filter, bool enable, const QVariant & option) {
+	/* Not used yet */
+	Q_UNUSED(filter);
+	Q_UNUSED(enable);
+	Q_UNUSED(option);
+};
+
 void MplayerProcess::changeStereo3DFilter(bool /*enable*/, const QString & /*in*/, const QString & /*out*/) {
 	// not supported
 }
