@@ -47,6 +47,7 @@ public:
 	void addStereo3DFilter(const QString & in, const QString & out);
 	void setSubStyles(const AssStyles & styles, const QString & assStylesFile = QString::null);
 	void setSubEncoding(const QString & codepage, const QString & enca_lang);
+	void setVideoEqualizerOptions(int contrast, int brightness, int hue, int saturation, int gamma, bool soft_eq);
 
 	// Slave commands
 	void quit();
@@ -67,11 +68,13 @@ public:
 	void showOSDText(const QString & text, int duration, int level);
 	void showFilenameOnOSD();
 	void showTimeOnOSD();
+
 	void setContrast(int value);
 	void setBrightness(int value);
 	void setHue(int value);
 	void setSaturation(int value);
 	void setGamma(int value);
+
 	void setChapter(int ID);
 	void nextChapter();
 	void previousChapter();
@@ -87,7 +90,10 @@ public:
 	void enableKaraoke(bool b);
 	void enableExtrastereo(bool b);
 	void enableVolnorm(bool b, const QString & option);
-	void setAudioEqualizer(const QString & values);
+#ifdef MPV_SUPPORT
+	void enableEarwax(bool /*b*/) {};
+#endif
+	void setAudioEqualizer(AudioEqualizerList);
 	void setAudioDelay(double delay);
 	void setSubDelay(double delay);
 	void setLoop(int v);
@@ -100,6 +106,7 @@ public:
 #endif
 	void setTitle(int ID);
 	void changeVF(const QString & filter, bool enable, const QVariant & option = QVariant());
+	void changeAF(const QString & filter, bool enable, const QVariant & option = QVariant());
 	void changeStereo3DFilter(bool enable, const QString & in, const QString & out);
 #if DVDNAV_SUPPORT
 	void discSetMousePos(int x, int y);
