@@ -25,6 +25,19 @@
 #include "config.h"
 
 #define OSD_WITH_TIMER
+//#define USE_OLD_VIDEO_EQ
+
+#ifndef USE_OLD_VIDEO_EQ
+class SoftVideoEq
+{
+public:
+	SoftVideoEq() { contrast = brightness = hue = saturation = gamma = 0; };
+	SoftVideoEq(int c, int b, int h, int s, int g) {
+		contrast = c; brightness = b; hue = h, saturation = s; gamma = g;
+	}
+	int contrast, brightness, hue, saturation, gamma;
+};
+#endif
 
 class QStringList;
 
@@ -50,6 +63,7 @@ public:
 	void addStereo3DFilter(const QString & in, const QString & out);
 	void setSubStyles(const AssStyles & styles, const QString & assStylesFile = QString::null);
 	void setSubEncoding(const QString & codepage, const QString & enca_lang);
+	void setVideoEqualizerOptions(int contrast, int brightness, int hue, int saturation, int gamma, bool soft_eq);
 
 	// Slave commands
 	void quit();
@@ -70,11 +84,13 @@ public:
 	void showOSDText(const QString & text, int duration, int level);
 	void showFilenameOnOSD();
 	void showTimeOnOSD();
+
 	void setContrast(int value);
 	void setBrightness(int value);
 	void setHue(int value);
 	void setSaturation(int value);
 	void setGamma(int value);
+
 	void setChapter(int ID);
 	void nextChapter();
 	void previousChapter();
@@ -85,12 +101,11 @@ public:
 	void seekSub(int value);
 	void setSubForcedOnly(bool b);
 	void setSpeed(double value);
-#ifdef MPLAYER_SUPPORT
 	void enableKaraoke(bool b);
-#endif
 	void enableExtrastereo(bool b);
 	void enableVolnorm(bool b, const QString & option);
-	void setAudioEqualizer(const QString & values);
+	void enableEarwax(bool b);
+	void setAudioEqualizer(AudioEqualizerList);
 	void setAudioDelay(double delay);
 	void setSubDelay(double delay);
 	void setLoop(int v);
@@ -103,6 +118,7 @@ public:
 #endif
 	void setTitle(int ID);
 	void changeVF(const QString & filter, bool enable, const QVariant & option = QVariant());
+	void changeAF(const QString & filter, bool enable, const QVariant & option = QVariant());
 	void changeStereo3DFilter(bool enable, const QString & in, const QString & out);
 #if DVDNAV_SUPPORT
 	void discSetMousePos(int x, int y);
@@ -127,6 +143,12 @@ protected:
 	bool isOptionAvailable(const QString & option);
 	void addVFIfAvailable(const QString & vf, const QString & value = QString::null);
 	void messageFilterNotSupported(const QString & filter_name);
+	QString lavfi(const QString & filter_name, const QVariant & option = QVariant());
+	QString audioEqualizerFilter(AudioEqualizerList);
+#ifndef USE_OLD_VIDEO_EQ
+	QString videoEqualizerFilter(SoftVideoEq);
+	void updateSoftVideoEqualizerFilter();
+#endif
 
 #ifdef OSD_WITH_TIMER
 	void toggleInfoOnOSD();
@@ -212,6 +234,13 @@ private:
 	int br_current_title;
 
 	QString previous_eq;
+	AudioEqualizerList previous_eq_list;
+
+#ifndef USE_OLD_VIDEO_EQ
+	bool use_soft_eq;
+	SoftVideoEq current_soft_eq;
+	SoftVideoEq previous_soft_eq;
+#endif
 
 #ifdef CAPTURE_STREAM
 	bool capturing;
