@@ -55,6 +55,7 @@ public:
 	virtual void addStereo3DFilter(const QString & in, const QString & out) = 0;
 	virtual void setSubStyles(const AssStyles & styles, const QString & assStylesFile = QString::null) = 0;
 	virtual void setSubEncoding(const QString & codepage, const QString & enca_lang) = 0;
+	virtual void setVideoEqualizerOptions(int contrast, int brightness, int hue, int saturation, int gamma, bool soft_eq) = 0;
 
 	// Slave commands
 	virtual void quit() = 0;
@@ -75,11 +76,13 @@ public:
 	virtual void showOSDText(const QString & text, int duration, int level) = 0;
 	virtual void showFilenameOnOSD() = 0;
 	virtual void showTimeOnOSD() = 0;
+
 	virtual void setContrast(int value) = 0;
 	virtual void setBrightness(int value) = 0;
 	virtual void setHue(int value) = 0;
 	virtual void setSaturation(int value) = 0;
 	virtual void setGamma(int value) = 0;
+
 	virtual void setChapter(int ID) = 0;
 	virtual void nextChapter() = 0;
 	virtual void previousChapter() = 0;
@@ -92,12 +95,13 @@ public:
 #endif
 	virtual void setSubForcedOnly(bool b) = 0;
 	virtual void setSpeed(double value) = 0;
-#ifdef MPLAYER_SUPPORT
 	virtual void enableKaraoke(bool b) = 0;
-#endif
 	virtual void enableExtrastereo(bool b) = 0;
 	virtual void enableVolnorm(bool b, const QString & option) = 0;
-	virtual void setAudioEqualizer(const QString & values) = 0;
+#ifdef MPV_SUPPORT
+	virtual void enableEarwax(bool b) = 0;
+#endif
+	virtual void setAudioEqualizer(AudioEqualizerList) = 0;
 	virtual void setAudioDelay(double delay) = 0;
 	virtual void setSubDelay(double delay) = 0;
 	virtual void setLoop(int v) = 0;
@@ -110,6 +114,7 @@ public:
 #endif
 	virtual void setTitle(int ID) = 0;
 	virtual void changeVF(const QString & filter, bool enable, const QVariant & option = QVariant()) = 0;
+	virtual void changeAF(const QString & filter, bool enable, const QVariant & option = QVariant()) = 0;
 	virtual void changeStereo3DFilter(bool enable, const QString & in, const QString & out) = 0;
 #if DVDNAV_SUPPORT
 	virtual void discSetMousePos(int x, int y) = 0;
