@@ -45,9 +45,9 @@
 #include "retrieveyoutubeurl.h"
 #endif
 
-//#define USE_CONFIG_VERSION
+#define USE_CONFIG_VERSION
 #ifdef USE_CONFIG_VERSION
-#define CURRENT_CONFIG_VERSION 4
+#define CURRENT_CONFIG_VERSION 5
 #endif
 
 using namespace Global;
@@ -81,11 +81,10 @@ void Preferences::reset() {
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	mplayer_bin= "mpv/mpv.exe";
-	if (QSysInfo::WindowsVersion < QSysInfo::WV_VISTA) {
+	if (QSysInfo::WindowsVersion < QSysInfo::WV_WINDOWS7) {
 		mplayer_bin= "mplayer/mplayer.exe";
 	}
 #else
-	//mplayer_bin = "mplayer";
 	mplayer_bin = "mpv";
 #endif
 
@@ -160,7 +159,11 @@ void Preferences::reset() {
 	softvol_max = 110; // 110 = default value in mplayer
 	use_scaletempo = Detect;
 	use_hwac3 = false;
+#ifdef Q_OS_WIN
 	use_audio_equalizer = true;
+#else
+	use_audio_equalizer = false;
+#endif
 
 	global_volume = true;
 	volume = 50;
@@ -363,7 +366,7 @@ void Preferences::reset() {
 
 	show_tag_in_window_title = true;
 
-	time_to_kill_mplayer = 1000;
+	time_to_kill_mplayer = 5000;
 
 #ifdef MPRIS2
 	use_mpris2 = true;
@@ -505,6 +508,7 @@ void Preferences::reset() {
 
 #ifdef MPV_SUPPORT
 	streaming_type = StreamingAuto;
+	ytdl_quality = "";
 #else
 	streaming_type = StreamingYT;
 #endif
@@ -901,7 +905,7 @@ void Preferences::save() {
 
 	set->setValue("show_tag_in_window_title", show_tag_in_window_title);
 
-	set->setValue("time_to_kill_mplayer", time_to_kill_mplayer);
+	set->setValue("time_to_kill_player", time_to_kill_mplayer);
 
 #ifdef MPRIS2
 	set->setValue("use_mpris2", use_mpris2);
@@ -1037,6 +1041,9 @@ void Preferences::save() {
 
 	set->beginGroup("streaming");
 	set->setValue("streaming_type", streaming_type);
+#ifdef MPV_SUPPORT
+	set->setValue("ytdl_quality", ytdl_quality);
+#endif
 
 	#ifdef YOUTUBE_SUPPORT
 	set->beginGroup("streaming/youtube");
@@ -1104,7 +1111,7 @@ void Preferences::save() {
 
 	set->setValue("initial_deinterlace", initial_deinterlace);
 
-	set->setValue("initial_audio_channels", initial_audio_channels);
+	set->setValue("audio_channels", initial_audio_channels);
 	set->setValue("initial_stereo_mode", initial_stereo_mode);
 
 	set->setValue("initial_audio_track", initial_audio_track);
@@ -1476,7 +1483,7 @@ void Preferences::load() {
 
 	show_tag_in_window_title = set->value("show_tag_in_window_title", show_tag_in_window_title).toBool();
 
-	time_to_kill_mplayer = set->value("time_to_kill_mplayer", time_to_kill_mplayer).toInt();
+	time_to_kill_mplayer = set->value("time_to_kill_player", time_to_kill_mplayer).toInt();
 
 #ifdef MPRIS2
 	use_mpris2 = set->value("use_mpris2", use_mpris2).toBool();
@@ -1615,6 +1622,9 @@ void Preferences::load() {
 
 	set->beginGroup("streaming");
 	streaming_type = set->value("streaming_type", streaming_type).toInt();
+#ifdef MPV_SUPPORT
+	ytdl_quality = set->value("ytdl_quality", ytdl_quality).toString();
+#endif
 
 	#ifdef YOUTUBE_SUPPORT
 	set->beginGroup("streaming/youtube");
@@ -1679,7 +1689,7 @@ void Preferences::load() {
 
 	initial_deinterlace = set->value("initial_deinterlace", initial_deinterlace).toInt();
 
-	initial_audio_channels = set->value("initial_audio_channels", initial_audio_channels).toInt();
+	initial_audio_channels = set->value("audio_channels", initial_audio_channels).toInt();
 	initial_stereo_mode = set->value("initial_stereo_mode", initial_stereo_mode).toInt();
 
 	initial_audio_track = set->value("initial_audio_track", initial_audio_track).toInt();
@@ -1806,11 +1816,21 @@ void Preferences::load() {
 			frame_drop = false;
 			cache_for_files = 2048;
 			cache_for_streams = 2048;
-			time_to_kill_mplayer = 1000;
+			//time_to_kill_mplayer = 1000;
 
 			resize_method = Never;
 			//move_when_dragging = false;
 		}
+		if (config_version <= 5) {
+			#ifdef Q_OS_WIN
+			if (QSysInfo::WindowsVersion < QSysInfo::WV_WINDOWS7) {
+				mplayer_bin= "mplayer/mplayer.exe";
+			}
+			#else
+			use_audio_equalizer = false;
+			initial_volnorm = false;
+			#endif
+		}
 		config_version = CURRENT_CONFIG_VERSION;
 	}
 #endif
