@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -125,6 +125,7 @@ public:
 		bool ffwmv3vdpau;
 		bool ffvc1vdpau;
 		bool ffodivxvdpau;
+		bool ffhevcvdpau;
 		bool disable_video_filters;
 	} vdpau;
 #endif
@@ -161,6 +162,9 @@ public:
 	double osd_scale; // mpv
 	double subfont_osd_scale; // mplayer
 	int osd_delay; //<! Delay in ms to show the OSD.
+#ifdef MPV_SUPPORT
+	bool osd_fractions; //<! Show OSD times with milliseconds.
+#endif
 
 	QString file_settings_method; //!< Method to be used for saving file settings
 
@@ -483,6 +487,9 @@ public:
 
 	// Streaming
 	int streaming_type;
+#ifdef MPV_SUPPORT
+	QString ytdl_quality;
+#endif
 	#ifdef YOUTUBE_SUPPORT
 	int yt_quality;
 	QString yt_user_agent;
@@ -529,7 +536,7 @@ public:
 	//! 100 = 100% at the bottom
 	int initial_sub_pos;
 
-#ifndef ADD_BLACKBORDERS_FS
+#ifdef INITIAL_BLACKBORDERS
 	bool initial_blackborders;
 #endif
 
