@@ -114,6 +114,7 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 #endif
 
 	// Channels combo
+	channels_combo->addItem( "0", MediaSettings::ChDefault );
 	channels_combo->addItem( "2", MediaSettings::ChStereo );
 	channels_combo->addItem( "4", MediaSettings::ChSurround );
 	channels_combo->addItem( "6", MediaSettings::ChFull51 );
@@ -160,11 +161,12 @@ void PrefGeneral::retranslateStrings() {
 	player_combo->setCurrentIndex(player_item);
 #endif
 
-	channels_combo->setItemText(0, tr("2 (Stereo)") );
-	channels_combo->setItemText(1, tr("4 (4.0 Surround)") );
-	channels_combo->setItemText(2, tr("6 (5.1 Surround)") );
-	channels_combo->setItemText(3, tr("7 (6.1 Surround)") );
-	channels_combo->setItemText(4, tr("8 (7.1 Surround)") );
+	channels_combo->setItemText(0, tr("Default") );
+	channels_combo->setItemText(1, tr("2 (Stereo)") );
+	channels_combo->setItemText(2, tr("4 (4.0 Surround)") );
+	channels_combo->setItemText(3, tr("6 (5.1 Surround)") );
+	channels_combo->setItemText(4, tr("7 (6.1 Surround)") );
+	channels_combo->setItemText(5, tr("8 (7.1 Surround)") );
 
 	int deinterlace_item = deinterlace_combo->currentIndex();
 	deinterlace_combo->clear();
@@ -1188,7 +1190,7 @@ void PrefGeneral::createHelp() {
 		tr("If it's not checked, the audio equalizer values are saved along each file "
            "and loaded back when the file is played later.") );
 
-	setWhatsThis(hwac3_check, tr("AC3/DTS pass-through S/PDIF"),
+	setWhatsThis(hwac3_check, tr("AC3/DTS passthrough over S/PDIF and HDMI"),
 		tr("Uses hardware AC3 passthrough.") + "<br>" +
         tr("<b>Note:</b> none of the audio filters will be used when this "
            "option is enabled.") );
