@@ -38,9 +38,15 @@
 #include <QPixmapCache>
 #include <QImageWriter>
 #include <QImageReader>
+#include <QDebug>
 
 #include <cmath>
 
+#ifndef NO_SMPLAYER_SUPPORT
+#include "inforeader.h"
+#include "images.h"
+#endif
+
 #define RENAME_PICTURES 0
 
 #define N_OUTPUT_FRAMES 1
@@ -48,6 +54,10 @@
 // MPlayer2 doesn't support png outdir
 /* #define VP_USE_PNG_OUTDIR */
 
+#define FONT_STYLE "font-family:ubuntu,verdana,arial;"
+#define HEADER_STYLE "style=\"" FONT_STYLE " font-size:16px\""
+#define FOOTER_STYLE HEADER_STYLE
+
 VideoPreview::VideoPreview(QString mplayer_path, QWidget * parent) : QWidget(parent, Qt::Window)
 {
 	setMplayerPath(mplayer_path);
@@ -81,6 +91,7 @@ VideoPreview::VideoPreview(QString mplayer_path, QWidget * parent) : QWidget(par
 	w_contents->setPalette(p);
 
 	info = new QLabel(this);
+	info->setWordWrap(true);
 
 	foot = new QLabel(this);
 	foot->setAlignment(Qt::AlignRight);
@@ -108,6 +119,13 @@ VideoPreview::VideoPreview(QString mplayer_path, QWidget * parent) : QWidget(par
 	connect( button_box, SIGNAL(rejected()), this, SLOT(close()) );
 	connect( button_box->button(QDialogButtonBox::Save), SIGNAL(clicked()), this, SLOT(saveImage()) );
 
+	button_box->button(QDialogButtonBox::Close)->setDefault(true);
+	button_box->button(QDialogButtonBox::Close)->setText(tr("&Close"));
+	button_box->button(QDialogButtonBox::Save)->setText(tr("&Save"));
+#ifndef NO_SMPLAYER_SUPPORT
+	button_box->button(QDialogButtonBox::Save)->setIcon(Images::icon("save"));
+#endif
+
 	QVBoxLayout * my_layout = new QVBoxLayout;
 	my_layout->addWidget(scroll_area);
 	my_layout->addWidget(button_box);
@@ -145,7 +163,7 @@ void VideoPreview::retranslateStrings() {
 	progress->setWindowTitle(tr("Thumbnail Generator"));
 	progress->setCancelButtonText( tr("Cancel") );
 
-	foot->setText("<i>"+ tr("Generated by SMPlayer") +" </i>");
+	foot->setText("<i " FOOTER_STYLE "><b>http://smplayer.info</b></i>");
 }
 
 void VideoPreview::setMplayerPath(QString mplayer_path) {
@@ -226,9 +244,9 @@ bool VideoPreview::extractImages() {
 
 	int num_pictures = prop.n_cols * prop.n_rows;
 	length -= prop.initial_step;
-	int s_step = length / num_pictures;
+	double s_step = (double) length / num_pictures;
 
-	int current_time = prop.initial_step;
+	double current_time = prop.initial_step;
 
 	canceled = false;
 	progress->setLabelText(tr("Creating thumbnails..."));
@@ -271,21 +289,48 @@ bool VideoPreview::extractImages() {
 	return true;
 }
 
-bool VideoPreview::runPlayer(int seek, double aspect_ratio) {
+#if defined(Q_OS_LINUX) && !defined(NO_SMPLAYER_SUPPORT)
+bool VideoPreview::isOptionAvailableinMPV(const QString & option) {
+	static QStringList option_list;
+	static QString executable;
+
+	if (option_list.isEmpty() || executable != mplayer_bin) {
+		InfoReader * ir = InfoReader::obj(mplayer_bin);
+		ir->getInfo();
+		option_list = ir->optionList();
+		executable = mplayer_bin;
+	}
+	return option_list.contains(option);
+}
+#endif
+
+bool VideoPreview::runPlayer(double seek, double aspect_ratio) {
 	QStringList args;
 
 	if (PlayerID::player(mplayer_bin) == PlayerID::MPV) {
 		#ifdef MPV_SUPPORT
+		bool use_new_options = true;
+		#if defined(Q_OS_LINUX) && !defined(NO_SMPLAYER_SUPPORT)
+		if (!isOptionAvailableinMPV("--vo-image-format")) use_new_options = false;
+		#endif
+
 		// MPV
-		args << "--no-config" << "--no-audio" << "--no-cache";
+		args << "--no-config" << "--no-audio" << "--no-cache" << "--hr-seek=yes";
 		args << "--frames=" + QString::number(N_OUTPUT_FRAMES);
 		args << "--framedrop=no" << "--start=" + QString::number(seek);
 		if (aspect_ratio != 0) {
 			args << "--video-aspect=" + QString::number(aspect_ratio);
 		}
 		if (!prop.dvd_device.isEmpty()) args << "--dvd-device=" + prop.dvd_device;
-		QString format = (prop.extract_format == PNG) ? "png:png-compression=0" : "jpg";
-		args << QString("--vo=image=format=%1:outdir=\"%2\"").arg(format).arg(full_output_dir);
+		if (!use_new_options) {
+			QString format = (prop.extract_format == PNG) ? "png:png-compression=0" : "jpg";
+			args << QString("--vo=image=format=%1:outdir=\"%2\"").arg(format).arg(full_output_dir);
+		} else {
+			QString format = (prop.extract_format == PNG) ? "png" : "jpg";
+			args << "--vo-image-format=" + format << "--vo-image-outdir=" + full_output_dir;
+			args << "--vo=image";
+			if (prop.extract_format == PNG) args << "--vo-image-png-compression=0";
+		}
 
 		/*
 		#ifdef Q_OS_WIN
@@ -335,21 +380,27 @@ bool VideoPreview::runPlayer(int seek, double aspect_ratio) {
 
 	args << prop.input_video;
 
-	QString command = mplayer_bin + " ";
-	for (int n = 0; n < args.count(); n++) command = command + args[n] + " ";
-	qDebug("VideoPreview::runMplayer: command: %s", command.toUtf8().constData());
+	QString command = mplayer_bin + " " + args.join(" ");
+	qDebug() << "VideoPreview::runMplayer: command:" << command;
 
 	QProcess p;
 	#ifndef VP_USE_PNG_OUTDIR
 	p.setWorkingDirectory(full_output_dir);
 	#endif
 	p.start(mplayer_bin, args);
+
+	if (!p.waitForStarted()) {
+		qDebug("VideoPreview::runMplayer: error: the process didn't start");
+	}
+
 	if (!p.waitForFinished()) {
 		qDebug("VideoPreview::runMplayer: error running process");
 		error_message = tr("The mplayer process didn't run");
 		return false;
 	}
 
+	//qDebug() << "VideoPreview::runMplayer: process output:" << p.readAll();
+
 	return true;
 }
 
@@ -385,13 +436,30 @@ bool VideoPreview::addPicture(const QString & filename, int num, int time) {
 
 	// Add current time text
 	if (prop.display_osd) {
-		QString stime = QTime().addSecs(time).toString("hh:mm:ss");
-		QFont font("Arial");
+		QTime t(0,0);
+		QString stime = t.addSecs(time).toString("hh:mm:ss");
+		//qDebug() << "VideoPreview::addPicture: stime:" << stime << "time:" << time;
+		QFont font;
+		font.setPointSize(12);
 		font.setBold(true);
 		QPainter painter(&scaled_picture);
-		painter.setPen( Qt::white );
+		painter.setPen(Qt::white);
 		painter.setFont(font);
-		painter.drawText(scaled_picture.rect(), Qt::AlignRight | Qt::AlignBottom, stime);
+		//painter.drawText(scaled_picture.rect(), Qt::AlignRight | Qt::AlignBottom, stime);
+
+		// Set background
+		QFontMetrics fm(font);
+		int px_wide = fm.width(stime);
+		int px_high = fm.height();
+		QRect rect(scaled_picture.rect());
+		rect.setX(rect.width() - px_wide);
+		rect.setY(rect.height() - px_high);
+		rect.setWidth(px_wide);
+		rect.setHeight(px_high);
+		painter.fillRect(rect, QBrush(QColor(0, 0, 0, 128)));
+
+		// Draw text
+		painter.drawText(rect, Qt::AlignCenter, stime);
 	}
 
 	QLabel * l = new QLabel(this);
@@ -403,6 +471,12 @@ bool VideoPreview::addPicture(const QString & filename, int num, int time) {
 	return true;
 }
 
+#define ADD_INFO( data) \
+	{ \
+	text += data; \
+	if (count++ % 3 == 0) text += "</td><td>"; else text += "<br>"; \
+	}
+
 void VideoPreview::displayVideoInfo(const VideoInfo & i) {
 	// Display info about the video
 	QTime t(0,0);
@@ -422,30 +496,38 @@ void VideoPreview::displayVideoInfo(const VideoInfo & i) {
 	QString audio_bitrate = (i.audio_bitrate==0) ? no_info : tr("%1 kbps").arg(i.audio_bitrate/1000);
 	QString audio_rate = (i.audio_rate==0) ? no_info : tr("%1 Hz").arg(i.audio_rate);
 
-	info->setText(
-		"<b><font size=+1>" + i.filename +"</font></b>"
-		"<table cellspacing=4 cellpadding=4><tr>"
-		"<td>" +
-		tr("Size: %1 MB").arg(i.size / (1024*1024)) + "<br>" +
-		tr("Resolution: %1x%2").arg(i.width).arg(i.height) + "<br>" +
-		tr("Length: %1").arg(t.toString("hh:mm:ss")) +
-		"</td>"
-		"<td>" +
-		tr("Video format: %1").arg(i.video_format) + "<br>" +
-		tr("Frames per second: %1").arg(fps) + "<br>" +
-		tr("Aspect ratio: %1").arg(aspect) + //"<br>" +
-		"</td>"
-		"<td>" +
-		tr("Video bitrate: %1").arg(video_bitrate) + "<br>" +
-		tr("Audio bitrate: %1").arg(audio_bitrate) + "<br>" +
-		tr("Audio rate: %1").arg(audio_rate) + //"<br>" +
-		"</td>"
-		"</tr></table>" 
-	);
+	int count = 1;
+
+	QString text =
+		"<h2 " FONT_STYLE ">" + i.filename + "</h2>"
+		"<table cellspacing=4 cellpadding=4 " HEADER_STYLE ">"
+		"<tr><td>";
+
+	ADD_INFO(tr("Size: %1 MB").arg(i.size / (1024*1024)));
+	ADD_INFO(tr("Resolution: %1x%2").arg(i.width).arg(i.height));
+	ADD_INFO(tr("Length: %1").arg(t.toString("hh:mm:ss")));
+
+	if (i.fps && i.fps != 1000) ADD_INFO(tr("Frames per second: %1").arg(fps));
+	if (!i.video_format.isEmpty()) ADD_INFO(tr("Video format: %1").arg(i.video_format));
+	if (!i.audio_format.isEmpty()) ADD_INFO(tr("Audio format: %1").arg(i.audio_format));
+
+	ADD_INFO(tr("Aspect ratio: %1").arg(aspect));
+
+	if (i.video_bitrate) ADD_INFO(tr("Video bitrate: %1").arg(video_bitrate));
+	if (i.audio_bitrate) ADD_INFO(tr("Audio bitrate: %1").arg(audio_bitrate));
+	if (i.audio_rate) ADD_INFO(tr("Audio rate: %1").arg(audio_rate));
+
+	text += "</td></tr></table>";
+
+	//qDebug() << "VideoPreview::displayVideoInfo: text:" << text;
+
+	info->setText(text);
 	setWindowTitle( tr("Video preview") + " - " + i.filename );
 }
 
 void VideoPreview::cleanDir(QString directory) {
+	//return;
+
 	QStringList filter;
 	if (prop.extract_format == PNG) {
 		filter.append("*.png");
@@ -489,15 +571,16 @@ VideoInfo VideoPreview::getInfo(const QString & mplayer_path, const QString & fi
 		#ifdef MPV_SUPPORT
 		// MPV
 		args << "--term-playing-msg="
-                "ID_LENGTH=${=length}\n"
+                "ID_LENGTH=${=duration:${=length}}\n"
                 "ID_VIDEO_WIDTH=${=width}\n"
                 "ID_VIDEO_HEIGHT=${=height}\n"
-                "ID_VIDEO_FPS=${=fps}\n"
+                "ID_VIDEO_FPS=${=container-fps:${=fps}}\n"
                 "ID_VIDEO_ASPECT=${=video-aspect}\n"
                 "ID_VIDEO_BITRATE=${=video-bitrate}\n"
                 "ID_AUDIO_BITRATE=${=audio-bitrate}\n"
-                "ID_AUDIO_RATE=${=audio-samplerate}\n"
-                "ID_VIDEO_FORMAT=${=video-format}";
+                "ID_AUDIO_RATE=${audio-params/samplerate:${=audio-samplerate}}\n"
+                "ID_VIDEO_FORMAT=${video-format}\n"
+                "ID_AUDIO_FORMAT=${audio-codec-name}\n";
 
 		args << "--vo=null" << "-ao=null" << "--frames=1" << "--no-quiet" << "--no-cache" << "--no-config";
 		if (!prop.dvd_device.isEmpty()) args << "--dvd-device=" + prop.dvd_device;
@@ -518,6 +601,9 @@ VideoInfo VideoPreview::getInfo(const QString & mplayer_path, const QString & fi
 		#endif // MPLAYER_SUPPORT
 	}
 
+	QString command = mplayer_path + " " + args.join(" ").replace("\n", "\\n");//.replace("$", "\\$");
+	qDebug() << "VideoPreview::getInfo: command:" << command;
+
 	p.start(mplayer_path, args);
 
 	if (p.waitForFinished()) {
@@ -552,6 +638,8 @@ VideoInfo VideoPreview::getInfo(const QString & mplayer_path, const QString & fi
 				if (tag == "AUDIO_RATE") i.audio_rate = value.toInt();
 				else
 				if (tag == "VIDEO_FORMAT") i.video_format = value;
+				else
+				if (tag == "AUDIO_FORMAT") i.audio_format = value;
 			}
 		}
 	} else {
